Module bindings

Module bindings 

Re-exports

pub use value::JsCompiledFunction;
pub use value::OwnedJsValue;

Modules

convert
value

Structs

ClassId
ContextWrapper
Wraps a quickjs context.
OwnedObjectRef
Wraps an object from the quickjs runtime. Provides convenience property accessors.
OwnedValueRef
OwnedValueRef wraps a Javascript value from the quickjs runtime. It prevents leaks by ensuring that the inner value is deallocated on drop.
ResourceObject

Constants

TAG_EXCEPTION

Functions

make_cstring
Helper for creating CStrings.