pub struct OwnedValueRef<'a> { /* private fields */ }Expand description
OwnedValueRef wraps a Javascript value from the quickjs runtime. It prevents leaks by ensuring that the inner value is deallocated on drop.
Implementations
Sourceimpl<'a> OwnedValueRef<'a>
impl<'a> OwnedValueRef<'a>
pub fn new(context: &'a ContextWrapper, value: JSValue) -> Self
pub fn new_dup(context: &'a ContextWrapper, value: JSValue) -> Self
pub fn is_null(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_exception(&self) -> bool
pub fn is_object(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_compiled_function(&self) -> bool
pub fn to_string(&self) -> Result<String, ExecutionError>
pub fn to_value(&self) -> Result<JsValue, ValueError>
pub fn to_bool(&self) -> Result<bool, ValueError>