Re-exports
pub use value::JsCompiledFunction;pub use value::OwnedJsValue;
Modules
Structs
- ClassId
- Context
Wrapper - Wraps a quickjs context.
- Owned
Object Ref - Wraps an object from the quickjs runtime. Provides convenience property accessors.
- Owned
Value Ref - OwnedValueRef wraps a Javascript value from the quickjs runtime. It prevents leaks by ensuring that the inner value is deallocated on drop.
- Resource
Object
Constants
Functions
- make_
cstring - Helper for creating CStrings.